==> 1.1.0.tar.gz: test/src/network/rokeet_api_test.dart <==
import 'dart:io';

import 'package:flutter/widgets.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:http_mock_adapter/http_mock_adapter.dart';
import 'package:rokeet/rokeet.dart';
import 'package:rokeet/src/network/network.dart';
import 'package:rokeet/src/network/query_params.dart';

import '../utils.dart';

void main() {
  WidgetsFlutterBinding.ensureInitialized();
  group("Rokeet Api", () {
    late DioAdapter dioAdapter;
    late RokeetApi api;
    setUp(() {
      dioAdapter = DioAdapter();
      api = RokeetApiBuilder("https://localhost")
          .clientAdapter(dioAdapter)
          .build();

      RWidgetParser.parsers[RLabelWidget.TYPE] =
          (json) => RLabelWidget.jsonParser(json);
      RWidgetParser.parsers[RButtonWidget.TYPE] =
          (json) => RButtonWidget.jsonParser(json);
      RWidgetParser.parsers[RVerticalContainerWidget.TYPE] =
          RVerticalContainerWidget.jsonParser;
    });

    test("get app should return status 200", () async {
      var clientId = "clientId";
      var clientSecret = "clientSecret";
      dioAdapter.onGet(
          "/apps",
          (request) => request.reply(
                200,
                loadJson("app/appconfig"),
              ),
          queryParameters: {
            QueryParams.clientId: clientId,
            QueryParams.clientSecret: clientSecret
          },
          headers: {
            HttpHeaders.userAgentHeader: "rokeet-Unknown-(en_US)"
          });
      var appConfig = await api.getApp(clientId, clientSecret);
      expect(appConfig, isNotNull);
      expect(appConfig.initStep, equals("login"));
    });

    test("get step should return status 200", () async {
      dioAdapter.onGet(
          "/steps",
          (request) => request.reply(
                200,
                loadJson("app/login_step"),
              ),
          queryParameters: {QueryParams.id: 'login'},
          headers: {HttpHeaders.userAgentHeader: "rokeet-Unknown-(en_US)"});
      var step = await api.getStep('login');
      expect(step, isNotNull);
      expect(step.body!.children!.length, equals(4));
    });
  });
}

==> 1.3.0.tar.gz: test/src/network/rokeet_api_test.dart <==
import 'dart:io';

import 'package:flutter/widgets.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:http_mock_adapter/http_mock_adapter.dart';
import 'package:rokeet/rokeet.dart';
import 'package:rokeet/src/network/client/dio/dio_http_client.dart';
import 'package:rokeet/src/network/network.dart';
import 'package:rokeet/src/network/query_params.dart';

import '../utils.dart';

void main() {
  WidgetsFlutterBinding.ensureInitialized();
  group("Rokeet Api", () {
    late DioAdapter dioAdapter;
    late HttpClient httpClient;
    late RokeetApi api;
    setUp(() {
      dioAdapter = DioAdapter();
      httpClient = DioHttpClient.builder()
          .withBaseUrl("https://localhost")
          .withClientAdapter(dioAdapter)
          .build();
      api = RokeetApi(httpClient);
      RWidgetParser.parsers[RLabelWidget.TYPE] =
          (json) => RLabelWidget.jsonParser(json);
      RWidgetParser.parsers[RButtonWidget.TYPE] =
          (json) => RButtonWidget.jsonParser(json);
      RWidgetParser.parsers[RVerticalContainerWidget.TYPE] =
          RVerticalContainerWidget.jsonParser;
    });

    test("get app should return status 200", () async {
      var clientId = "clientId";
      var clientSecret = "clientSecret";
      dioAdapter.onGet(
          "/apps",
          (request) => request.reply(
                200,
                loadJson("app/appconfig"),
              ),
          queryParameters: {
            QueryParams.clientId: clientId,
            QueryParams.clientSecret: clientSecret
          },
          headers: {
            HttpHeaders.userAgentHeader: "rokeet-Unknown-(en_US)"
          });
      var appConfig = await api.getApp(clientId, clientSecret);
      expect(appConfig, isNotNull);
      expect(appConfig.initStep, equals("login"));
    });

    test("get step should return status 200", () async {
      dioAdapter.onGet(
          "/steps",
          (request) => request.reply(
                200,
                loadJson("app/login_step"),
              ),
          queryParameters: {QueryParams.id: 'login'},
          headers: {HttpHeaders.userAgentHeader: "rokeet-Unknown-(en_US)"});
      var step = await api.getStep('login');
      expect(step, isNotNull);
      expect(step.body!.children!.length, equals(4));
    });
  });
}
